@@ -9,6 +9,7 @@ Provides:
 - OpenAPI documentation
 """
 
-from aii.api.server import APIServer, generate_api_key
+from aii.api.server import APIServer
+from aii.api.utils import generate_api_key
 
 __all__ = ["APIServer", "generate_api_key"]
