@@ -122,6 +122,7 @@ class AiiCLIClient:
         user_input: str,
         output_mode: Optional[str] = None,
         offline: bool = False,
+        model: Optional[str] = None,  # v0.8.0: Model override
         spinner = None,  # Optional spinner to stop when streaming starts
         **kwargs
     ) -> Dict[str, Any]:
@@ -139,6 +140,7 @@ class AiiCLIClient:
             user_input: User's natural language prompt
             output_mode: Output mode (clean, standard, thinking)
             offline: Whether to run in offline mode
+            model: Optional model override (e.g., 'kimi-k2-thinking', 'gpt-4.1-mini')
             spinner: Optional spinner instance to stop when streaming starts
             **kwargs: Additional parameters
 
@@ -200,6 +202,11 @@ class AiiCLIClient:
                     "offline": offline,
                     **kwargs
                 }
+
+                # v0.8.0: Add model override if provided
+                if model:
+                    request["model"] = model
+
                 debug_print(f"CLIENT: Sending unified request (LLM-first): user_prompt={user_input[:50]}...")
 
                 # Track if we've cleared the loading indicator
