@@ -88,6 +88,13 @@ class CommandParser:
             help="API server host:port (default: localhost:16169). Example: --host localhost:16170",
         )
 
+        # Model override option (v0.8.0)
+        parser.add_argument(
+            "--model",
+            type=str,
+            help="Override LLM model for this request (e.g., kimi-k2-thinking, gpt-4.1-mini, claude-sonnet-4.5)",
+        )
+
         # Output mode options (mutually exclusive)
         output_mode_group = parser.add_mutually_exclusive_group()
         output_mode_group.add_argument(
@@ -460,12 +467,86 @@ class CommandParser:
         prompt_parser.set_defaults(prompt_action="help")
 
     def _add_stats_commands(self, subparsers: Any) -> None:
-        """Add statistics and analytics commands (v0.4.7)"""
+        """Add statistics and analytics commands (v0.4.7, v0.9.0)"""
         stats_parser = subparsers.add_parser(
             "stats",
             help="Usage statistics and analytics"
         )
 
+        # Create subcommands for v0.9.0
+        stats_subparsers = stats_parser.add_subparsers(
+            dest="stats_action", required=False
+        )
+
+        # v0.9.0: stats models - Model performance analytics
+        models_parser = stats_subparsers.add_parser(
+            "models",
+            help="Model performance statistics (success rates, latency, token usage)"
+        )
+        models_parser.add_argument(
+            "--period",
+            type=str,
+            choices=["7d", "30d", "90d", "all"],
+            default="30d",
+            help="Time period for statistics (default: 30d)"
+        )
+        models_parser.add_argument(
+            "--category",
+            type=str,
+            help="Filter by function category (e.g., translation, analysis, code)"
+        )
+        models_parser.add_argument(
+            "--format",
+            type=str,
+            choices=["table", "json"],
+            default="table",
+            help="Output format (default: table)"
+        )
+
+        # v0.9.0: stats cost - Cost analytics
+        cost_parser = stats_subparsers.add_parser(
+            "cost",
+            help="Cost analytics with breakdowns and trends"
+        )
+        cost_parser.add_argument(
+            "--period",
+            type=str,
+            choices=["7d", "30d", "90d", "all"],
+            default="30d",
+            help="Time period for statistics (default: 30d)"
+        )
+        cost_parser.add_argument(
+            "--breakdown-by",
+            type=str,
+            choices=["model", "category", "provider", "client", "all"],
+            default="model",
+            help="Breakdown dimension (default: model)"
+        )
+        cost_parser.add_argument(
+            "--show-trends",
+            action="store_true",
+            help="Show usage and cost growth trends"
+        )
+        cost_parser.add_argument(
+            "--show-top-spenders",
+            action="store_true",
+            help="Show top spending functions"
+        )
+        cost_parser.add_argument(
+            "--top-limit",
+            type=int,
+            default=10,
+            help="Number of top spenders to show (default: 10)"
+        )
+        cost_parser.add_argument(
+            "--format",
+            type=str,
+            choices=["table", "json"],
+            default="table",
+            help="Output format (default: table)"
+        )
+
+        # Legacy v0.4.7 stats (no subcommand - fallback to old behavior)
         # Period filter
         stats_parser.add_argument(
             "--period",
@@ -750,6 +831,7 @@ class CommandParser:
             "config": "~/.aii/config.yaml",
             "api_key": None,
             "host": None,  # v0.6.0: API server host:port
+            "model": None,  # v0.8.0: Model override
             "verbose": False,
             "minimal": False,
             "debug": False,
@@ -787,6 +869,12 @@ class CommandParser:
                     i += 2
                 else:
                     i += 1
+            elif arg == "--model":  # v0.8.0: Model override
+                if i + 1 < len(args):
+                    extracted_options["model"] = args[i + 1]
+                    i += 2
+                else:
+                    i += 1
             elif arg == "--verbose" or arg == "-v":
                 extracted_options["verbose"] = True
                 i += 1
