@@ -210,29 +210,27 @@ async def _handle_config_set(args: dict, config_manager: Any) -> int:
 
         # Validate specific keys
         if key == "llm.model":
-            # Get available models for validation
-            from aii.cli.setup.steps.model_selection import ModelSelectionStep
+            # Get available models for validation (v0.9.3: use model_registry)
+            from aii.data.providers.model_registry import get_models_for_provider, get_model_metadata
             provider = config_manager.get("llm.provider", "anthropic")
-            step = ModelSelectionStep()
-            provider_models = step.MODELS.get(provider, {})
+            valid_model_ids = get_models_for_provider(provider)
 
-            if provider_models:
-                valid_model_ids = [m["id"] for m in provider_models.get("models", {}).values()]
-                if value not in valid_model_ids:
-                    print(f"⚠️  Warning: '{value}' is not in the list of recommended models for {provider}")
-                    print(f"\n📋 Available {provider} models:")
-                    for m in provider_models.get("models", {}).values():
-                        marker = " ✓" if m.get("recommended") else ""
-                        print(f"  - {m['id']}{marker}")
+            if valid_model_ids and value not in valid_model_ids:
+                print(f"⚠️  Warning: '{value}' is not in the list of recommended models for {provider}")
+                print(f"\n📋 Available {provider} models:")
+                for model_id in valid_model_ids:
+                    metadata = get_model_metadata(provider, model_id)
+                    display_name = metadata.get("display_name", model_id)
+                    print(f"  - {model_id} ({display_name})")
 
-                    # Ask for confirmation
-                    confirm = input("\n❓ Continue anyway? (y/N): ").strip().lower()
-                    if confirm not in ['y', 'yes']:
-                        print("❌ Model change cancelled")
-                        return 1
+                # Ask for confirmation
+                confirm = input("\n❓ Continue anyway? (y/N): ").strip().lower()
+                if confirm not in ['y', 'yes']:
+                    print("❌ Model change cancelled")
+                    return 1
 
         elif key == "llm.provider":
-            valid_providers = ["anthropic", "openai", "gemini"]
+            valid_providers = ["anthropic", "openai", "gemini", "moonshot", "deepseek"]
             if value not in valid_providers:
                 print(f"❌ Error: Invalid provider '{value}'")
                 print(f"Valid providers: {', '.join(valid_providers)}")
@@ -261,7 +259,8 @@ async def _handle_config_model(args: dict, config_manager: Any) -> int:
     model_id = args.get("model_id")
 
     if not model_id:
-        # Show current model and available options
+        # Show current model and available options (v0.9.3: use model_registry)
+        from aii.data.providers.model_registry import get_models_for_provider, get_model_metadata
         from aii.cli.setup.steps.model_selection import ModelSelectionStep
         provider = config_manager.get("llm.provider", "anthropic")
         current_model = config_manager.get("llm.model")
@@ -270,42 +269,45 @@ async def _handle_config_model(args: dict, config_manager: Any) -> int:
         print(f"\n✨ Available {provider} models:")
 
         step = ModelSelectionStep()
-        provider_models = step.MODELS.get(provider, {})
-        if provider_models:
-            for num, info in provider_models.get("models", {}).items():
-                marker = " ✓ (recommended)" if info.get("recommended") else ""
-                current = " ← current" if info["id"] == current_model else ""
-                print(f"  {info['name']}{marker}{current}")
-                print(f"    {info['description']}")
-                print(f"    ID: {info['id']}\n")
+        available_models = get_models_for_provider(provider)
+        recommended_default = step.RECOMMENDED_DEFAULTS.get(provider)
+
+        if available_models:
+            for model_id in available_models:
+                metadata = get_model_metadata(provider, model_id)
+                display_name = metadata.get("display_name", model_id)
+                description = metadata.get("description", "")
+
+                marker = " ✓ (recommended)" if model_id == recommended_default else ""
+                current = " ← current" if model_id == current_model else ""
+                print(f"  {display_name}{marker}{current}")
+                print(f"    {description}")
+                print(f"    ID: {model_id}\n")
 
         print("Usage: aii config model <model_id>")
         print("\n💡 Tip: You can also use custom model IDs not listed above")
         return 0
 
-    # Set the model using the existing set logic
+    # Set the model using the existing set logic (v0.9.3: use model_registry)
     try:
-        from aii.cli.setup.steps.model_selection import ModelSelectionStep
+        from aii.data.providers.model_registry import get_models_for_provider
         provider = config_manager.get("llm.provider", "anthropic")
-        step = ModelSelectionStep()
-        provider_models = step.MODELS.get(provider, {})
+        valid_model_ids = get_models_for_provider(provider)
 
-        if provider_models:
-            valid_model_ids = [m["id"] for m in provider_models.get("models", {}).values()]
-            if model_id not in valid_model_ids:
-                # Custom model ID - ask for confirmation
-                print(f"⚠️  '{model_id}' is not in the list of recommended models for {provider}")
-                print(f"\nThis appears to be a custom model ID.")
-                print(f"Available models: {', '.join(valid_model_ids[:3])}...")
-                print(f"\nRun 'aii config model' to see all available models")
+        if valid_model_ids and model_id not in valid_model_ids:
+            # Custom model ID - ask for confirmation
+            print(f"⚠️  '{model_id}' is not in the list of recommended models for {provider}")
+            print(f"\nThis appears to be a custom model ID.")
+            print(f"Available models: {', '.join(valid_model_ids[:3])}...")
+            print(f"\nRun 'aii config model' to see all available models")
 
-                # Ask for confirmation
-                confirm = input(f"\nProceed with custom model '{model_id}'? (y/n): ").strip().lower()
-                if confirm != 'y':
-                    print("❌ Model change cancelled")
-                    return 1
+            # Ask for confirmation
+            confirm = input(f"\nProceed with custom model '{model_id}'? (y/n): ").strip().lower()
+            if confirm != 'y':
+                print("❌ Model change cancelled")
+                return 1
 
-                print(f"\n💡 Note: Ensure '{model_id}' is a valid model ID for {provider}")
+            print(f"\n💡 Note: Ensure '{model_id}' is a valid model ID for {provider}")
 
         config_manager.set("llm.model", model_id, save=True)
         print(f"✅ Model updated to: {model_id}")
@@ -331,22 +333,23 @@ async def _handle_config_provider(args: dict, config_manager: Any) -> int:
         print("  1. anthropic - Claude models (Sonnet, Opus, Haiku)")
         print("  2. openai    - GPT models (GPT-4o, GPT-4 Turbo)")
         print("  3. gemini    - Google Gemini models (2.5 Flash, 1.5 Pro)")
+        print("  4. moonshot  - Moonshot AI (Long context up to 256K)")
+        print("  5. deepseek  - DeepSeek AI (Ultra low cost)")
         print("\nUsage: aii config provider <provider_name>")
         print("\n⚠️  Note: Changing provider may require setting a new model")
         return 0
 
     # Validate provider
-    valid_providers = ["anthropic", "openai", "gemini"]
+    valid_providers = ["anthropic", "openai", "gemini", "moonshot", "deepseek"]
     if provider_name not in valid_providers:
         print(f"❌ Error: Invalid provider '{provider_name}'")
         print(f"Valid providers: {', '.join(valid_providers)}")
         return 1
 
-    # Get default model for new provider
+    # Get default model for new provider (v0.9.3: use model_registry)
     from aii.cli.setup.steps.model_selection import ModelSelectionStep
     step = ModelSelectionStep()
-    provider_models = step.MODELS.get(provider_name, {})
-    default_model = provider_models.get("default", "")
+    default_model = step.RECOMMENDED_DEFAULTS.get(provider_name, "")
 
     if not default_model:
         print(f"❌ Error: No default model found for {provider_name}")
