@@ -107,7 +107,8 @@ class InteractiveShell:
                         result = await self.engine.process_input(
                             user_input,
                             context=self.current_context,
-                            status_display=self.status_display  # Pass status_display for spinner control
+                            status_display=self.status_display,  # Pass status_display for spinner control
+                            client_type="cli"  # v0.9.2: Track CLI usage
                         )
 
                         # Stop loading animation (only if streaming didn't stop it already)
