@@ -23,6 +23,8 @@ from typing import Any
 
 import yaml
 
+from aii.data.providers.model_migration import migrate_model_if_needed
+
 
 class ConfigManager:
     """Manage AII configuration files and settings"""
@@ -143,6 +145,9 @@ class ConfigManager:
         if self.secrets_file.exists():
             os.chmod(self.secrets_file, 0o600)
 
+        # v0.9.3: Check for deprecated models and auto-migrate
+        self._migrate_deprecated_model()
+
     def _deep_merge(self, default: dict, override: dict) -> dict:
         """Deep merge two dictionaries"""
         result = default.copy()
@@ -213,6 +218,26 @@ class ConfigManager:
         if save:
             self.save_secrets()
 
+    def _migrate_deprecated_model(self) -> None:
+        """
+        Check if configured model is deprecated and auto-migrate to replacement.
+
+        v0.9.3: Auto-migration for deprecated models (gpt-3.5-turbo, claude-3-*, etc.)
+        """
+        configured_model = self.get("llm.model")
+
+        if not configured_model:
+            # No model configured yet, nothing to migrate
+            return
+
+        # Check if migration is needed
+        migrated_model = migrate_model_if_needed(configured_model, warn=True)
+
+        if migrated_model != configured_model:
+            # Model was migrated, update config
+            self.set("llm.model", migrated_model, save=True)
+            print(f"✅ Configuration updated: {configured_model} → {migrated_model}\n")
+
     def get_output_mode(self, function_name: str) -> str | None:
         """
         Get configured output mode for a function.
