@@ -69,7 +69,24 @@ class AIIEngine:
         # Initialize budget manager (SRP: extracted from engine)
         self.budget_manager = BudgetManager(self.cost_calculator, self.output_config)
 
-        self.execution_engine = ExecutionEngine(self.function_registry, self.cost_calculator)
+        # Initialize chat storage first (v0.4.7)
+        from ..data.storage.chat_storage import ChatStorage
+        self.chat_storage = ChatStorage(self.storage_path / "chats.db")
+
+        # Initialize execution logger for model intelligence (v0.9.0)
+        from .execution.execution_logger import ExecutionLogger
+        self.execution_logger = ExecutionLogger(
+            storage=self.chat_storage,
+            batch_size=10,
+            batch_timeout_ms=100
+        )
+        self._logger_started = False  # Track if logger has been started
+
+        self.execution_engine = ExecutionEngine(
+            self.function_registry,
+            self.cost_calculator,
+            self.execution_logger
+        )
         self.output_formatter = OutputFormatter(
             use_colors=self.output_config.use_colors,
             use_emojis=self.output_config.use_emojis
@@ -98,10 +115,6 @@ class AIIEngine:
         # Initialize conversation manager for enhanced context
         self.conversation_manager: ConversationManager | None = None
 
-        # Initialize chat storage for execution logging (v0.4.7)
-        from ..data.storage.chat_storage import ChatStorage
-        self.chat_storage = ChatStorage(self.storage_path / "chats.db")
-
         # External integrations (to be injected)
         self.llm_provider: Any | None = None
         self.web_client: Any | None = None
@@ -207,9 +220,15 @@ class AIIEngine:
         session_id: str | None = None,
         status_display: Any | None = None,
         output_mode_override: OutputMode | None = None,  # CLI flag override
+        client_type: str = "cli",  # v0.9.2: Track client source
     ) -> FormattedOutput:
         """Main input processing pipeline with enhanced context management"""
         try:
+            # Start execution logger on first request (v0.9.0)
+            if not self._logger_started:
+                await self.execution_logger.start()
+                self._logger_started = True
+
             # Track total wall-clock time from user's perspective
             import time
             total_start_time = time.time()
@@ -241,6 +260,7 @@ class AIIEngine:
                         user_input=user_input,
                         function_name="",
                         parameters={},
+                        client_type=client_type,
                         llm_provider=self.llm_provider,
                         web_client=self.web_client,
                         mcp_client=self.mcp_client,
@@ -573,6 +593,32 @@ class AIIEngine:
                 success=execution_result.success
             )
 
+            # Step 4.4.1: Log execution metrics for analytics (v0.9.0)
+            try:
+                from .models import ExecutionContext as AnalyticsContext
+
+                # Create execution context for analytics
+                analytics_context = AnalyticsContext(
+                    chat_context=context,
+                    user_input=user_input,
+                    function_name=recognition_result.function_name,
+                    parameters=recognition_result.parameters,
+                    llm_provider=self.llm_provider,
+                    web_client=self.web_client,
+                )
+
+                # Log execution (non-blocking, <5ms)
+                execution_time_ms = int(execution_result.execution_time * 1000) if execution_result.execution_time else 0
+                await self.execution_logger.log_execution(
+                    result=execution_result,
+                    context=analytics_context,
+                    execution_time_ms=execution_time_ms,
+                    ttft_ms=None,  # TTFT not currently tracked
+                )
+            except Exception as e:
+                # Don't fail the request if analytics logging fails
+                logger.warning(f"Failed to log execution metrics: {e}")
+
             # Step 4.5: Add conversation turn if conversation manager is available
             if self.conversation_manager:
                 try:
@@ -1115,7 +1161,7 @@ class AIIEngine:
         return self.output_formatter.format_help(help_data)
 
     async def execute_function(
-        self, function_name: str, parameters: dict[str, Any]
+        self, function_name: str, parameters: dict[str, Any], client_type: str = "cli"
     ) -> ExecutionResult:
         """Execute a function directly by name"""
         # Create a minimal execution context
@@ -1124,6 +1170,7 @@ class AIIEngine:
             user_input="",
             function_name=function_name,
             parameters=parameters,
+            client_type=client_type,
             llm_provider=self.llm_provider,
             web_client=self.web_client,
             mcp_client=self.mcp_client,
@@ -1245,6 +1292,7 @@ class AIIEngine:
                         user_input=user_input,
                         function_name=recognition_result.function_name,
                         parameters=recognition_result.parameters,
+                        client_type=client_type,
                         llm_provider=self.llm_provider,
                         web_client=self.web_client,
                         mcp_client=self.mcp_client,
@@ -1271,6 +1319,7 @@ class AIIEngine:
                         user_input=user_input,
                         function_name=recognition_result.function_name,
                         parameters=recognition_result.parameters,
+                        client_type=client_type,
                         llm_provider=self.llm_provider,
                         web_client=self.web_client,
                         mcp_client=self.mcp_client,
@@ -1300,6 +1349,7 @@ class AIIEngine:
                         user_input=user_input,
                         function_name=recognition_result.function_name,
                         parameters=recognition_result.parameters,
+                        client_type=client_type,
                         llm_provider=self.llm_provider,
                         web_client=self.web_client,
                         mcp_client=self.mcp_client,
@@ -1326,6 +1376,7 @@ class AIIEngine:
                         user_input=user_input,
                         function_name=recognition_result.function_name,
                         parameters=recognition_result.parameters,
+                        client_type=client_type,
                         llm_provider=self.llm_provider,
                         web_client=self.web_client,
                         mcp_client=self.mcp_client,
@@ -1571,6 +1622,7 @@ class AIIEngine:
                 user_input="",
                 function_name="",
                 parameters={},
+                client_type="cli",  # Default to CLI for create_session
                 llm_provider=self.llm_provider,
                 web_client=self.web_client,
                 mcp_client=self.mcp_client,
