@@ -35,10 +35,16 @@ from ..cost.calculator import CostCalculator
 class ExecutionEngine:
     """Orchestrates function execution with monitoring and error handling"""
 
-    def __init__(self, function_registry: FunctionRegistry, cost_calculator: CostCalculator | None = None):
+    def __init__(
+        self,
+        function_registry: FunctionRegistry,
+        cost_calculator: CostCalculator | None = None,
+        execution_logger: Any = None  # ExecutionLogger (v0.9.0)
+    ):
         """Initialize execution engine"""
         self.function_registry = function_registry
         self.cost_calculator = cost_calculator
+        self.execution_logger = execution_logger
         self.performance_metrics: list[PerformanceMetrics] = []
         self.max_metrics_history = 1000
 
@@ -54,6 +60,7 @@ class ExecutionEngine:
         offline_mode: bool = False,
         streaming_callback: Any = None,  # Optional[Callable[[str], Awaitable[None]]]
         websocket_handler: Any = None,  # v0.6.0: WebSocket handler for MCP client delegation
+        client_type: str = "cli",  # v0.9.2: Track client source
     ) -> ExecutionResult:
         """Execute a function based on recognition result"""
         start_time = time.time()
@@ -72,6 +79,7 @@ class ExecutionEngine:
             user_input=user_input,
             function_name=actual_function_name,  # Use intent for execution
             parameters=recognition_result.parameters,
+            client_type=client_type,  # v0.9.2: Track client source
             llm_provider=llm_provider,
             web_client=web_client,
             mcp_client=mcp_client,
@@ -156,6 +164,10 @@ class ExecutionEngine:
                     artifacts = [f"commit:{result.data['commit_hash']}"]
 
             # Calculate cost if cost calculator is available
+            # SINGLE SOURCE OF TRUTH: Cost Calculation
+            # This is the ONLY place where LLM costs are calculated for execution tracking
+            # All downstream components (ExecutionLogger, stats functions, API endpoints) use this value
+            # Never recalculate cost from tokens elsewhere - this ensures 100% consistency
             cost = 0.0
             provider_name = None
             model_name = None
@@ -165,7 +177,7 @@ class ExecutionEngine:
                     provider_name = getattr(llm_provider, 'provider_name', 'unknown')
                     model_name = getattr(llm_provider, 'model_name', 'unknown')
 
-                    # Calculate cost
+                    # Calculate cost using CostCalculator (single source of truth)
                     cost_breakdown = self.cost_calculator.calculate_cost(
                         provider=provider_name,
                         model=model_name,
@@ -191,6 +203,8 @@ class ExecutionEngine:
                 result.data['reasoning_tokens'] = reasoning_tokens
 
             # v0.6.0: Always add cost (even if 0) for consistent session summary display
+            # Store cost in result.data for downstream consumption (ExecutionLogger, stats, API)
+            # This is the authoritative cost value - downstream components must never recalculate
             result.data['cost'] = cost
 
             if os.getenv("AII_DEBUG"):
@@ -225,6 +239,21 @@ class ExecutionEngine:
                 # Add to session
                 session.add_function_execution(function_execution)
 
+            # Log execution to database (v0.9.0 - non-blocking)
+            if self.execution_logger:
+                try:
+                    await self.execution_logger.log_execution(
+                        result=result,
+                        context=context,
+                        execution_time_ms=int(execution_time * 1000),
+                        ttft_ms=None,  # TODO: Track TTFT in streaming callback
+                        client_type=context.client_type  # v0.9.2: Track client source
+                    )
+                except Exception as e:
+                    # Don't crash on logging errors
+                    import logging
+                    logging.getLogger(__name__).error(f"Failed to log execution: {e}")
+
             result.execution_time = execution_time
             return result
 
@@ -254,6 +283,32 @@ class ExecutionEngine:
                 )
                 session.add_function_execution(function_execution)
 
+            # Create error result for logging
+            error_result = ExecutionResult(
+                success=False,
+                message=str(e),
+                function_name=recognition_result.function_name,
+                data={
+                    "error_code": type(e).__name__,
+                    "error_message": str(e),
+                }
+            )
+
+            # Log failed execution to database (v0.9.0 - non-blocking)
+            if self.execution_logger:
+                try:
+                    await self.execution_logger.log_execution(
+                        result=error_result,
+                        context=context,
+                        execution_time_ms=int(execution_time * 1000),
+                        ttft_ms=None,
+                        client_type=context.client_type  # v0.9.2: Track client source
+                    )
+                except Exception as log_err:
+                    # Don't crash on logging errors
+                    import logging
+                    logging.getLogger(__name__).error(f"Failed to log execution: {log_err}")
+
             # Create error context for detailed error handling
             error_context = ErrorContext(
                 function_name=recognition_result.function_name,
