@@ -24,6 +24,7 @@ from typing import Any
 from ..context.models import ChatContext
 from ..models import FunctionSafety, RecognitionResult, RouteSource
 from .models import BUILT_IN_INTENTS, IntentTemplate
+from .parameter_enhancers import get_enhancer_registry
 
 # LLMOrchestrator imported dynamically when needed to avoid circular imports
 
@@ -41,6 +42,9 @@ class IntentRecognizer:
         self.function_registry: Any | None = None  # Will be injected
         self.recognition_cache: dict[str, RecognitionResult] = {}
 
+        # Initialize enhancer registry for parameter enhancement
+        self.enhancer_registry = get_enhancer_registry()
+
     def register_function_registry(self, registry: Any) -> None:
         """Register function registry for dynamic function discovery"""
         self.function_registry = registry
@@ -739,41 +743,13 @@ Rules:
 
                 parameters = cleaned_parameters
 
-            # Enhanced parameter mapping for code generation
-            if data.get("intent") == "code_generate":
-                parameters = self._enhance_code_generate_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for code review
-            if data.get("intent") == "code_review":
-                parameters = self._enhance_code_review_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for explain function
-            if data.get("intent") == "explain":
-                parameters = self._enhance_explain_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for email generation
-            if data.get("intent") == "generate_email":
-                parameters = self._enhance_email_generate_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for git diff
-            if data.get("intent") == "git_diff":
-                parameters = self._enhance_git_diff_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for summarize
-            if data.get("intent") == "summarize":
-                parameters = self._enhance_summarize_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for translate
-            if data.get("intent") == "translate":
-                parameters = self._enhance_translate_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for research
-            if data.get("intent") == "research":
-                parameters = self._enhance_research_parameters(parameters, user_input)
-
-            # Enhanced parameter mapping for MCP tool
-            if data.get("intent") == "mcp_tool":
-                parameters = self._enhance_mcp_tool_parameters(parameters, user_input)
+            # Enhanced parameter mapping via registry
+            parameters = self.enhancer_registry.enhance(
+                function_name=data.get("intent"),
+                parameters=parameters,
+                user_input=user_input,
+                context=context
+            )
 
             return RecognitionResult(
                 intent=data["intent"],
@@ -791,581 +767,6 @@ Rules:
             print(f"Failed to parse LLM response: {e}")
             return None
 
-    def _enhance_explain_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for explain function with constraint intelligence"""
-        import re
-
-        # 0. PARAMETER NAME NORMALIZATION (LLM sometimes returns 'concept' instead of 'topic')
-        if "concept" in parameters and "topic" not in parameters:
-            parameters["topic"] = parameters.pop("concept")
-
-        # 1. WORD LIMIT DETECTION
-        word_limit_patterns = [
-            r"within (\d+) words?",
-            r"in (\d+) words? or less",
-            r"no more than (\d+) words?",
-            r"(\d+) words? max",
-            r"(\d+)-word explanation",
-            r"limit to (\d+) words?",
-            r"under (\d+) words?",
-            r"maximum (\d+) words?",
-        ]
-
-        for pattern in word_limit_patterns:
-            match = re.search(pattern, user_input.lower())
-            if match:
-                word_count = int(match.group(1))
-                parameters["max_words"] = word_count
-
-                # Auto-adjust brevity based on word count
-                if word_count <= 25:
-                    parameters["brevity"] = "brief"
-                elif word_count <= 75:
-                    parameters["brevity"] = "concise"
-                elif word_count <= 150:
-                    parameters["brevity"] = "standard"
-                else:
-                    parameters["brevity"] = "detailed"
-
-                # Force simple format for strict word limits (avoid structured headings)
-                if word_count <= 200:
-                    parameters["format_style"] = "paragraph"  # Single paragraph, no headings
-
-                break
-
-        # 2. BREVITY INDICATORS (order matters - most specific first)
-        brevity_patterns = [
-            (r"\b(brief|briefly|short|shortly|quick|quickly)\b", "brief"),
-            (r"\b(concise|concisely|succinct|terse)\b", "concise"),
-            (r"\b(extensive|exhaustive|comprehensive|complete|full)\b", "comprehensive"),
-            (r"\b(detailed|thorough|in-depth)\b", "detailed"),
-        ]
-
-        for pattern, brevity_level in brevity_patterns:
-            if re.search(pattern, user_input.lower()):
-                if "brevity" not in parameters:
-                    parameters["brevity"] = brevity_level
-                break
-
-        # 3. FORMAT CONSTRAINTS
-        format_patterns = {
-            r"\b(bullet points?|list|bulleted|points)\b": "bullet_points",
-            r"\b(one sentence|single sentence|definition only)\b": "definition",
-            r"\b(summary|summarize)\b": "summary",
-            r"\b(paragraph|prose)\b": "paragraph",
-        }
-
-        for pattern, format_style in format_patterns.items():
-            if re.search(pattern, user_input.lower()):
-                parameters["format_style"] = format_style
-                break
-
-        # 4. SPECIAL CONSTRAINTS
-        constraint_indicators = [
-            r"(no|without) (technical jargon|jargon|technical terms)",
-            r"(simple language|plain english|easy to understand)",
-            r"(one sentence|single sentence)",
-            r"(definition only|just the definition)",
-            r"(without examples|no examples)",
-        ]
-
-        constraints = []
-        for pattern in constraint_indicators:
-            if re.search(pattern, user_input.lower()):
-                constraints.append(re.search(pattern, user_input.lower()).group())
-
-        if constraints:
-            parameters["constraints"] = "; ".join(constraints)
-
-        # 5. HANDLE EXAMPLES BASED ON CONSTRAINTS
-        if re.search(r"\b(without examples|no examples|skip examples)\b", user_input.lower()):
-            parameters["include_examples"] = False
-
-        if DEBUG_MODE: print(f"🔍 DEBUG: Enhanced explain parameters: {parameters}")
-        return parameters
-
-    def _enhance_code_generate_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for code_generate function with language detection"""
-        import re
-
-        # If LLM didn't provide specification, create it from the original input
-        if "specification" not in parameters:
-            # Extract the core request without language indicators
-            spec_patterns = [
-                r"write me an? (\w+) implementation (?:for|of) (.+)",  # "write me a Golang implementation for X"
-                r"(?:create|write|implement|generate) (?:a )?(.+) in (\w+)",  # "create X in Python"
-                r"(?:create|write|implement|generate) (?:a )?(\w+) (.+)",  # "create Python script"
-                r"(?:create|write|implement|generate) (.+)",  # "create edit distance algorithm"
-            ]
-
-            specification = user_input
-            detected_language = None
-
-            for pattern in spec_patterns:
-                match = re.search(pattern, user_input, re.IGNORECASE)
-                if match:
-                    groups = match.groups()
-                    if len(groups) == 2:
-                        # Pattern with language and specification
-                        lang_candidate, spec_candidate = groups
-                        if self._is_programming_language(lang_candidate):
-                            detected_language = lang_candidate.lower()
-                            specification = spec_candidate
-                        elif self._is_programming_language(spec_candidate):
-                            detected_language = spec_candidate.lower()
-                            specification = lang_candidate
-                        else:
-                            specification = f"{lang_candidate} {spec_candidate}"
-                    else:
-                        specification = groups[0]
-                    break
-
-            parameters["specification"] = specification
-
-            # Set detected language if found
-            if detected_language and "language" not in parameters:
-                # Map common language names to standard ones
-                language_mapping = {
-                    "golang": "go",
-                    "go": "go",
-                    "python": "python",
-                    "py": "python",
-                    "javascript": "javascript",
-                    "js": "javascript",
-                    "typescript": "typescript",
-                    "ts": "typescript",
-                    "java": "java",
-                    "c++": "cpp",
-                    "cpp": "cpp",
-                    "rust": "rust",
-                    "rs": "rust",
-                }
-                parameters["language"] = language_mapping.get(detected_language, detected_language)
-
-        # Language detection from input if not already set
-        if "language" not in parameters or parameters.get("language") in [None, "", "auto"]:
-            language_patterns = [
-                (r"\b(golang|go)\b", "go"),
-                (r"\b(python|py)\b", "python"),
-                (r"\b(javascript|js)\b", "javascript"),
-                (r"\b(typescript|ts)\b", "typescript"),
-                (r"\b(java)\b", "java"),
-                (r"\b(c\+\+|cpp)\b", "cpp"),
-                (r"\b(rust|rs)\b", "rust"),
-            ]
-
-            for pattern, lang in language_patterns:
-                if re.search(pattern, user_input, re.IGNORECASE):
-                    parameters["language"] = lang
-                    break
-
-            # Default to auto if still not detected
-            if "language" not in parameters:
-                parameters["language"] = "auto"
-
-        # Ensure language is a valid choice
-        valid_languages = ["python", "javascript", "typescript", "java", "cpp", "go", "rust", "text", "auto"]
-        if parameters.get("language") not in valid_languages:
-            parameters["language"] = "auto"
-
-        if DEBUG_MODE: print(f"🔍 DEBUG: Enhanced code_generate parameters: {parameters}")
-        return parameters
-
-    def _is_programming_language(self, text: str) -> bool:
-        """Check if text is a programming language name"""
-        languages = ["golang", "go", "python", "py", "javascript", "js", "typescript", "ts",
-                    "java", "c++", "cpp", "rust", "rs"]
-        return text.lower() in languages
-
-    def _enhance_code_review_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for code_review function with path extraction"""
-        import re
-
-        # If LLM didn't provide file_path, extract it from user input
-        if "file_path" not in parameters:
-            # Common patterns for code review requests
-            path_patterns = [
-                r"analyze (?:the )?code in (?:the )?(?:folder|directory) (.+)",
-                r"review (?:the )?code in (?:the )?(?:folder|directory) (.+)",
-                r"analyze (?:the )?(?:folder|directory) (.+)",
-                r"review (?:the )?(?:folder|directory) (.+)",
-                r"analyze (?:the )?file (.+)",
-                r"review (?:the )?file (.+)",
-                r"code review (?:for|of) (.+)",
-                r"check (?:the )?code in (.+)",
-                r"examine (?:the )?code in (.+)",
-            ]
-
-            for pattern in path_patterns:
-                match = re.search(pattern, user_input, re.IGNORECASE)
-                if match:
-                    file_path = match.group(1).strip()
-                    # Clean up common artifacts
-                    file_path = file_path.replace(" folder", "").replace(" directory", "")
-                    file_path = file_path.strip('"\'')
-                    parameters["file_path"] = file_path
-                    break
-
-            # If still no path found, try to extract any path-like string
-            if "file_path" not in parameters:
-                # Look for path-like patterns (contains / or specific folder names)
-                path_candidates = re.findall(r'[a-zA-Z_][a-zA-Z0-9_/.-]*[a-zA-Z0-9_]', user_input)
-                for candidate in path_candidates:
-                    if '/' in candidate or any(folder in candidate.lower() for folder in ['core', 'src', 'lib', 'functions', 'utils']):
-                        parameters["file_path"] = candidate
-                        break
-
-        # Focus area detection
-        if "focus" not in parameters:
-            focus_patterns = {
-                r"\b(security|secure|vulnerability|vulnerabilities)\b": "security",
-                r"\b(performance|speed|optimize|optimization|efficient)\b": "performance",
-                r"\b(style|format|formatting|convention|conventions)\b": "style",
-                r"\b(all|everything|complete|comprehensive|full)\b": "all",
-            }
-
-            for pattern, focus_value in focus_patterns.items():
-                if re.search(pattern, user_input, re.IGNORECASE):
-                    parameters["focus"] = focus_value
-                    break
-
-            # Default focus
-            if "focus" not in parameters:
-                parameters["focus"] = "all"
-
-        if DEBUG_MODE: print(f"🔍 DEBUG: Enhanced code_review parameters: {parameters}")
-        return parameters
-
-    def _enhance_email_generate_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for generate_email function with purpose extraction"""
-        import re
-
-        # Extract the purpose from the user input
-        # Remove common email generation prefixes to get the core purpose
-        purpose_patterns = [
-            r"write (?:a |an )?(?:professional )?email (declining|accepting|about|regarding|for|to) (.+)",
-            r"generate (?:a |an )?(?:professional )?email (declining|accepting|about|regarding|for|to) (.+)",
-            r"create (?:a |an )?(?:professional )?email (declining|accepting|about|regarding|for|to) (.+)",
-            r"compose (?:a |an )?(?:professional )?email (declining|accepting|about|regarding|for|to) (.+)",
-            r"draft (?:a |an )?(?:professional )?email (declining|accepting|about|regarding|for|to) (.+)",
-            r"write (?:a |an )?(?:professional )?email (.+)",
-            r"generate (?:a |an )?(?:professional )?email (.+)",
-            r"create (?:a |an )?(?:professional )?email (.+)",
-        ]
-
-        purpose = user_input  # Default fallback
-        for pattern in purpose_patterns:
-            match = re.search(pattern, user_input, re.IGNORECASE)
-            if match:
-                if len(match.groups()) == 2:
-                    # Pattern with action and object (e.g., "declining a meeting")
-                    action, obj = match.groups()
-                    purpose = f"{action} {obj}".strip()
-                else:
-                    # Simple pattern with just the purpose
-                    purpose = match.group(1).strip()
-                break
-
-        # Clean up the purpose
-        purpose = purpose.strip('"\'.,!?')
-        if not purpose:
-            purpose = user_input
-
-        parameters["purpose"] = purpose
-
-        # Detect recipient type from context
-        recipient_patterns = {
-            "client": ["client", "customer"],
-            "manager": ["manager", "supervisor", "boss"],
-            "team": ["team", "colleagues", "everyone"],
-            "external": ["external", "vendor", "partner"],
-        }
-
-        recipient_type = "colleague"  # Default
-        user_lower = user_input.lower()
-        for rec_type, keywords in recipient_patterns.items():
-            if any(keyword in user_lower for keyword in keywords):
-                recipient_type = rec_type
-                break
-
-        parameters["recipient_type"] = recipient_type
-
-        # Detect tone from input
-        tone_patterns = {
-            "formal": ["formal", "official"],
-            "friendly": ["friendly", "casual", "warm"],
-            "urgent": ["urgent", "asap", "immediate", "quickly"],
-        }
-
-        tone = "professional"  # Default
-        for tone_type, keywords in tone_patterns.items():
-            if any(keyword in user_lower for keyword in keywords):
-                tone = tone_type
-                break
-
-        parameters["tone"] = tone
-
-        return parameters
-
-    def _enhance_git_diff_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for git_diff function with commit detection"""
-        import re
-
-        # Detect if user wants to see changes in a specific commit
-        commit_patterns = [
-            r"(?:what|show)\s+changed\s+in\s+(?:the\s+)?last\s+commit",
-            r"(?:what|show)\s+(?:was\s+)?in\s+(?:the\s+)?last\s+commit",
-            r"diff\s+(?:of\s+)?(?:the\s+)?last\s+commit",
-            r"(?:what|show)\s+changed\s+in\s+(?:the\s+)?(?:latest|recent)\s+commit",
-            r"show\s+(?:me\s+)?(?:the\s+)?(?:latest|last|recent)\s+commit",
-            r"(?:what|show)\s+changed\s+in\s+HEAD",
-            r"git\s+show",
-        ]
-
-        user_lower = user_input.lower()
-        for pattern in commit_patterns:
-            if re.search(pattern, user_lower):
-                parameters["commit"] = "HEAD"
-                parameters["analyze"] = True  # Auto-enable analysis for commit diffs
-                break
-
-        # Detect if user wants staged changes
-        if any(keyword in user_lower for keyword in ["staged", "cached", "--cached"]):
-            parameters["staged"] = True
-
-        # Detect if user wants to analyze the diff
-        if any(keyword in user_lower for keyword in ["analyze", "analysis", "explain", "review"]):
-            parameters["analyze"] = True
-
-        return parameters
-
-    def _enhance_summarize_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for summarize function with content extraction"""
-        import re
-
-        # Extract content from various summarize command patterns
-        content_patterns = [
-            r"summarize\s+this\s+article\s+in\s+\w+:\s*[\"'](.+?)[\"']",
-            r"summarize\s+this\s+text\s+in\s+\w+:\s*[\"'](.+?)[\"']",
-            r"summarize\s+this\s+in\s+\w+:\s*[\"'](.+?)[\"']",
-            r"summarize\s+this\s+article:\s*[\"'](.+?)[\"']",
-            r"summarize\s+this\s+text:\s*[\"'](.+?)[\"']",
-            r"summarize\s+this:\s*[\"'](.+?)[\"']",
-            r"summarize\s+[\"'](.+?)[\"']",
-            r"create\s+(?:a\s+)?summary\s+of\s+this:\s*(.+?)(?:\.\s+output|\.\s+write|\.\s+please|\.$|$)",
-            r"summarize\s+this\s+article\s+in\s+\w+:\s*(.+)",
-            r"summarize\s+this\s+text\s+in\s+\w+:\s*(.+)",
-            r"summarize\s+this\s+in\s+\w+:\s*(.+)",
-            r"summarize\s+this\s+article:\s*(.+)",
-            r"summarize\s+this\s+text:\s*(.+)",
-            r"summarize\s+this:\s*(.+)",
-            r"summarize\s+(.+)",
-        ]
-
-        content = ""
-        for pattern in content_patterns:
-            match = re.search(pattern, user_input, re.IGNORECASE | re.DOTALL)
-            if match:
-                content = match.group(1).strip()
-                # Clean up common artifacts
-                content = content.strip('"\'')
-                # Remove escaped characters that might come from shell
-                content = content.replace('\\', '')
-                break
-
-        if content:
-            parameters["content"] = content
-
-        # Detect language preference
-        language_patterns = {
-            r"in\s+chinese": "chinese",
-            r"in\s+english": "english",
-            r"in\s+spanish": "spanish",
-            r"in\s+french": "french",
-            r"in\s+german": "german",
-            r"in\s+japanese": "japanese",
-            r"in\s+korean": "korean",
-            r"in\s+italian": "italian",
-            r"in\s+portuguese": "portuguese",
-            r"output.*in\s+chinese\s+language": "chinese",
-            r"output.*in\s+english\s+language": "english",
-            r"output.*in\s+spanish\s+language": "spanish",
-            r"output.*in\s+french\s+language": "french",
-            r"write.*in\s+chinese": "chinese",
-            r"write.*in\s+english": "english",
-            r"用中文": "chinese",
-            r"用英文": "english",
-        }
-
-        for pattern, language in language_patterns.items():
-            if re.search(pattern, user_input.lower()):
-                parameters["language"] = language
-                break
-
-        # Detect length preferences
-        length_patterns = {
-            r"(?:brief|short|concise|brief summary)": "brief",
-            r"(?:long|detailed|comprehensive|in-depth)": "detailed",
-            r"(?:bullet|bullets|bullet points|list)": "bullet_points",
-            r"(?:executive|executive summary)": "executive",
-        }
-
-        for pattern, length_type in length_patterns.items():
-            if re.search(pattern, user_input.lower()):
-                if length_type == "bullet_points":
-                    parameters["format"] = "bullet_points"
-                elif length_type == "executive":
-                    parameters["format"] = "executive"
-                elif length_type == "brief":
-                    parameters["length"] = "brief"
-                elif length_type == "detailed":
-                    parameters["length"] = "detailed"
-                break
-
-        return parameters
-
-    def _enhance_translate_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for translate function with text and language extraction"""
-        import re
-
-        # Extract text to translate from various patterns
-        text_patterns = [
-            r"translate\s+this\s+to\s+\w+:\s*[\"'](.+?)[\"']",  # translate this to spanish: "text"
-            r"translate\s+this\s+to\s+\w+:\s*(.+)$",  # translate this to spanish: text
-            r"translate\s+[\"'](.+?)[\"']\s+to\s+\w+",  # translate "text" to spanish
-            r"translate\s+(.+?)\s+to\s+\w+",  # translate text to spanish
-            r"translate\s+[\"'](.+?)[\"']",  # translate "text"
-            r"translate:\s*(.+)$",  # translate: text
-            r"translate\s+(.+)$",  # translate text (last resort)
-        ]
-
-        text = ""
-        for pattern in text_patterns:
-            match = re.search(pattern, user_input, re.IGNORECASE | re.DOTALL)
-            if match:
-                text = match.group(1).strip()
-                # Clean up common artifacts
-                text = text.strip('"\'')
-                # Remove trailing punctuation if it's part of the command
-                if text.endswith('.') and len(text) < 50:  # Only remove period from short texts
-                    text = text.rstrip('.')
-                break
-
-        if text:
-            parameters["text"] = text
-
-        # Extract target language
-        target_language_patterns = {
-            r"to\s+spanish": "spanish",
-            r"to\s+french": "french",
-            r"to\s+german": "german",
-            r"to\s+english": "english",
-            r"to\s+chinese": "chinese",
-            r"to\s+japanese": "japanese",
-            r"to\s+korean": "korean",
-            r"to\s+italian": "italian",
-            r"to\s+portuguese": "portuguese",
-            r"to\s+russian": "russian",
-            r"to\s+arabic": "arabic",
-            r"in\s+spanish": "spanish",
-            r"in\s+french": "french",
-            r"in\s+german": "german",
-            r"in\s+english": "english",
-            r"in\s+chinese": "chinese",
-            r"in\s+japanese": "japanese",
-            r"in\s+korean": "korean",
-        }
-
-        for pattern, language in target_language_patterns.items():
-            if re.search(pattern, user_input.lower()):
-                parameters["target_language"] = language
-                break
-
-        # Extract source language if specified
-        source_language_patterns = {
-            r"from\s+spanish": "spanish",
-            r"from\s+french": "french",
-            r"from\s+german": "german",
-            r"from\s+english": "english",
-            r"from\s+chinese": "chinese",
-            r"from\s+japanese": "japanese",
-            r"from\s+korean": "korean",
-        }
-
-        for pattern, language in source_language_patterns.items():
-            if re.search(pattern, user_input.lower()):
-                parameters["source_language"] = language
-                break
-
-        return parameters
-
-    def _enhance_research_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for research function with query extraction"""
-        import re
-
-        # Extract research query from various patterns
-        query_patterns = [
-            r"research\s+(?:about\s+|on\s+|the\s+)?(.+?)(?:\s+with\s+\d+\s+sources|\s+in\s+detail|\s+comprehensively|$)",
-            r"research:\s*(.+)$",
-            r"look\s+up\s+(?:information\s+(?:about\s+|on\s+))?(.+)$",
-            r"find\s+(?:information\s+(?:about\s+|on\s+))?(.+)$",
-            r"search\s+(?:for\s+)?(?:information\s+(?:about\s+|on\s+))?(.+)$",
-        ]
-
-        query = ""
-        for pattern in query_patterns:
-            match = re.search(pattern, user_input, re.IGNORECASE | re.DOTALL)
-            if match:
-                query = match.group(1).strip()
-                # Clean up common artifacts
-                query = query.strip('"\'')
-                # Remove trailing punctuation that's part of the command
-                if query.endswith('.') and len(query) < 100:
-                    query = query.rstrip('.')
-                break
-
-        # If no pattern matched, use the whole input minus the trigger word
-        if not query:
-            query = re.sub(r'^(?:research|look\s+up|find|search)\s+', '', user_input, flags=re.IGNORECASE).strip()
-
-        if query:
-            parameters["query"] = query
-
-        # Extract depth preference
-        depth_patterns = {
-            r"(?:brief|quick|overview|high-level)": "overview",
-            r"(?:detailed|thorough)": "detailed",
-            r"(?:comprehensive|in-depth|extensive|complete)": "comprehensive",
-        }
-
-        for pattern, depth_level in depth_patterns.items():
-            if re.search(pattern, user_input.lower()):
-                parameters["depth"] = depth_level
-                break
-
-        # Extract number of sources if specified
-        sources_match = re.search(r"(\d+)\s+sources?", user_input.lower())
-        if sources_match:
-            try:
-                parameters["sources"] = int(sources_match.group(1))
-            except ValueError:
-                pass
-
-        return parameters
-
-    def _enhance_mcp_tool_parameters(self, parameters: dict, user_input: str) -> dict:
-        """Enhanced parameter mapping for mcp_tool function
-
-        MCP tool function expects a 'user_request' parameter containing the full
-        natural language request. The function will then use LLM to select the
-        appropriate MCP tool and generate arguments.
-        """
-        # Always provide the full user input as user_request
-        # This allows the MCP function to do its own tool selection
-        parameters["user_request"] = user_input
-
-        return parameters
-
     def _force_contextual_parameters(
         self,
         original_params: dict[str, Any],
