@@ -13,7 +13,7 @@ Key Components:
 - defaults.py: Built-in default server configurations
 - config_loader.py: Configuration loading with priority system
 - client_manager.py: Multi-server connection management
-- models.py: AII-specific data models
+- models.py: Aii-specific data models
 
 MCP Specification: https://modelcontextprotocol.io/specification/2025-06-18
 Python SDK: https://github.com/modelcontextprotocol/python-sdk
