@@ -644,7 +644,7 @@ class WebSearchClient:
             async with self.session.get(
                 url,
                 timeout=aiohttp.ClientTimeout(total=30),
-                headers={"User-Agent": "AII-Bot/1.0 (https://github.com/aiiware/aii)"},
+                headers={"User-Agent": "Aii-Bot/1.0 (https://github.com/aiiware/aii)"},
             ) as response:
                 if response.status == 200:
                     content = await response.text()
