@@ -155,6 +155,11 @@ class LLMProvider(ABC):
         """Get the provider name (e.g., 'OpenAI', 'Anthropic')"""
         return self.__class__.__name__.replace("Provider", "")
 
+    @property
+    def model_name(self) -> str:
+        """Get the model name (alias for self.model for backward compatibility)"""
+        return self.model
+
     @property
     def model_info(self) -> str:
         """Get formatted model information (e.g., 'OpenAI:gpt-4')"""
@@ -271,7 +276,7 @@ class OpenAIProvider(LLMProvider):
                     if chunk.choices[0].delta.content:
                         delta = chunk.choices[0].delta.content
                         accumulated_text += delta
-                        on_token(delta)
+                        await on_token(delta)
 
                     # Capture usage from final chunk if available
                     if hasattr(chunk, "usage") and chunk.usage:
@@ -321,7 +326,19 @@ class OpenAIProvider(LLMProvider):
                     finish_reason=response.choices[0].finish_reason,
                 )
         except Exception as e:
-            raise RuntimeError(f"OpenAI completion with usage failed: {str(e)}") from e
+            # Check for content filter errors (OpenAI, Moonshot, etc.)
+            error_str = str(e)
+            if "content_filter" in error_str or "considered high risk" in error_str:
+                provider_name = getattr(self, 'provider_name', 'LLM provider')
+                raise RuntimeError(
+                    f"Content filtered by {provider_name}: The request was rejected due to content policy. "
+                    f"This content may contain sensitive topics (politics, violence, etc.). "
+                    f"Try using a different model (Claude, Gemini, DeepSeek) which have less restrictive filters."
+                ) from e
+
+            # Generic error for other failures
+            provider_name = getattr(self, 'provider_name', 'LLM provider')
+            raise RuntimeError(f"{provider_name} completion failed: {str(e)}") from e
 
     async def complete_with_tools(
         self,
@@ -381,6 +398,46 @@ class OpenAIProvider(LLMProvider):
             await self.client.close()
 
 
+class OpenAICompatibleProvider(OpenAIProvider):
+    """OpenAI-compatible provider for Moonshot, DeepSeek, and other compatible APIs"""
+
+    def __init__(self, api_key: str, model: str, base_url: str, provider_name: str = None):
+        """
+        Initialize OpenAI-compatible provider with custom base URL.
+
+        Args:
+            api_key: API key for the provider
+            model: Model name (e.g., 'kimi-k2-thinking', 'deepseek-chat')
+            base_url: Custom API base URL (e.g., 'https://api.moonshot.ai/v1')
+            provider_name: Provider name for cost calculation (e.g., 'moonshot', 'deepseek')
+        """
+        self.base_url = base_url
+        self._provider_name = provider_name  # Store for cost calculation
+        # Call parent constructor
+        LLMProvider.__init__(self, api_key, model)
+        self.client = None
+        self._initialize_client()
+
+    @property
+    def provider_name(self) -> str:
+        """Override to return actual provider name for cost calculation"""
+        return self._provider_name if self._provider_name else "openai"
+
+    def _initialize_client(self):
+        """Initialize OpenAI client with custom base URL"""
+        try:
+            import openai
+
+            self.client = openai.AsyncOpenAI(
+                api_key=self.api_key,
+                base_url=self.base_url
+            )
+        except ImportError as e:
+            raise ImportError(
+                "OpenAI package not installed. Install with: pip install openai"
+            ) from e
+
+
 class AnthropicProvider(LLMProvider):
     """Anthropic Claude provider implementation with subscription support"""
 
@@ -1186,7 +1243,24 @@ def create_llm_provider(
     provider_name = provider_name.lower()
     # Creating LLM provider
 
-    # Use Pydantic AI if requested
+    # Handle OpenAI-compatible providers FIRST (bypass Pydantic AI)
+    # Moonshot and DeepSeek use OpenAI SDK with custom base URLs
+    if provider_name == "moonshot":
+        return OpenAICompatibleProvider(
+            api_key=api_key,
+            model=model or "kimi-k2-turbo-preview",
+            base_url="https://api.moonshot.ai/v1",
+            provider_name="moonshot"
+        )
+    elif provider_name == "deepseek":
+        return OpenAICompatibleProvider(
+            api_key=api_key,
+            model=model or "deepseek-chat",
+            base_url="https://api.deepseek.com",
+            provider_name="deepseek"
+        )
+
+    # Use Pydantic AI if requested (for other providers)
     if use_pydantic_ai:
         try:
             from .pydantic_ai_provider import create_pydantic_ai_provider
@@ -1214,3 +1288,68 @@ def create_llm_provider(
         )  # api_key is model_path for local
     else:
         raise ValueError(f"Unsupported LLM provider: {provider_name}")
+
+
+async def create_temporary_provider(
+    provider_name: str,
+    model: str,
+    config_manager
+) -> LLMProvider:
+    """
+    Create a temporary LLM provider for a single request.
+
+    This allows per-request model overrides without affecting the server's
+    default provider configuration.
+
+    Args:
+        provider_name: Provider name (openai, anthropic, gemini, moonshot, deepseek)
+        model: Model name to use
+        config_manager: ConfigManager instance for API key lookup
+
+    Returns:
+        LLMProvider instance configured for the specified model
+
+    Raises:
+        ValueError: If provider_name is not supported
+        RuntimeError: If API key for provider is not configured
+
+    Example:
+        >>> temp_provider = await create_temporary_provider(
+        ...     provider_name="moonshot",
+        ...     model="kimi-k2-thinking",
+        ...     config_manager=config_manager
+        ... )
+        >>> response = await temp_provider.complete("hello")
+    """
+    # Validate provider
+    valid_providers = ["openai", "anthropic", "gemini", "moonshot", "deepseek"]
+    if provider_name not in valid_providers:
+        raise ValueError(
+            f"Unsupported provider: {provider_name}. "
+            f"Valid providers: {', '.join(valid_providers)}"
+        )
+
+    # Get API key for provider
+    api_key_map = {
+        "openai": "openai_api_key",
+        "anthropic": "anthropic_api_key",
+        "gemini": "gemini_api_key",
+        "moonshot": "moonshot_api_key",
+        "deepseek": "deepseek_api_key"
+    }
+
+    api_key = config_manager.get_secret(api_key_map[provider_name])
+    if not api_key:
+        raise RuntimeError(
+            f"API key for {provider_name} not configured. "
+            f"Set {api_key_map[provider_name].upper()} environment variable "
+            f"or run 'aii config provider {provider_name}'"
+        )
+
+    # Create provider instance (reuse existing factory)
+    return create_llm_provider(
+        provider_name=provider_name,
+        api_key=api_key,
+        model=model,
+        use_pydantic_ai=True  # Use default behavior
+    )
