@@ -66,13 +66,31 @@ class PydanticAIProvider(LLMProvider):
             self._underlying_provider_name = "unknown"
             self._underlying_model_name = model_name
 
+        if DEBUG_MODE:
+            print(f"DEBUG PydanticAIProvider init: provider_name={provider_name}, model_name={model_name}")
+            print(f"DEBUG PydanticAIProvider init: _underlying_provider_name={self._underlying_provider_name}, _underlying_model_name={self._underlying_model_name}")
+
         self._initialize_client()
 
     def _initialize_client(self):
         """Initialize Pydantic AI model and agent"""
         try:
-            # Infer the model from the model name
-            self._model = infer_model(self.model)
+            # Try to infer the model from the model name
+            try:
+                self._model = infer_model(self.model)
+                if DEBUG_MODE:
+                    print(f"DEBUG _initialize_client: infer_model succeeded for {self.model}")
+            except Exception as infer_error:
+                # If infer_model fails (e.g., unknown OpenAI-compatible model),
+                # pass the model string directly to Agent
+                if self.model.startswith("openai:"):
+                    if DEBUG_MODE:
+                        print(f"DEBUG _initialize_client: infer_model failed, using model string directly: {self.model}")
+                    # Agent can accept a string model name directly
+                    self._model = self.model
+                else:
+                    # Re-raise if not an OpenAI model
+                    raise infer_error
 
             # Create a basic agent for text completion
             self._agent = Agent(
@@ -167,84 +185,160 @@ class PydanticAIProvider(LLMProvider):
         if not self._agent:
             raise RuntimeError("Pydantic AI agent not initialized")
 
-        try:
-            # Check if streaming is requested and supported
-            if on_token is not None:
-                # Use streaming path
-                result = await self._complete_with_streaming(prompt, on_token, **kwargs)
-            else:
-                # Use non-streaming path
-                result = await self._agent.run(prompt)
+        # Retry configuration for rate limit errors
+        max_retries = 3
+        base_delay = 2.0  # seconds
+        max_delay = 10.0  # seconds
 
-            # Extract usage information from the result
-            usage = {}
+        last_error = None
 
-            # Call the usage() method to get actual usage data
-            usage_data = None
-            if hasattr(result, "usage"):
-                try:
-                    usage_data = result.usage()  # Call the method!
-                except Exception as e:
-                    # Fallback if usage() method fails
-                    pass
+        for attempt in range(max_retries + 1):
+            try:
+                # Sanitize prompt to fix Unicode surrogate issues (common with emoji)
+                # This handles cases where emojis or special characters cause encoding errors
+                sanitized_prompt = prompt.encode('utf-8', errors='surrogatepass').decode('utf-8', errors='replace')
 
-            if usage_data:
-                # Pydantic AI usage structure may vary
-                # Use new field names first, fall back to deprecated ones
-                import warnings
-                with warnings.catch_warnings():
-                    warnings.filterwarnings("ignore", category=DeprecationWarning)
-
-                    if hasattr(usage_data, "input_tokens"):
-                        usage["input_tokens"] = usage_data.input_tokens or 0
-                    elif hasattr(usage_data, "request_tokens"):
-                        usage["input_tokens"] = usage_data.request_tokens or 0
-
-                    if hasattr(usage_data, "output_tokens"):
-                        usage["output_tokens"] = usage_data.output_tokens or 0
-                    elif hasattr(usage_data, "response_tokens"):
-                        usage["output_tokens"] = usage_data.response_tokens or 0
-
-                if hasattr(usage_data, "total_tokens"):
-                    usage["total_tokens"] = usage_data.total_tokens or 0
+                # Check if streaming is requested and supported
+                if on_token is not None:
+                    # Use streaming path
+                    result = await self._complete_with_streaming(sanitized_prompt, on_token, **kwargs)
                 else:
-                    # Calculate total if not available
-                    usage["total_tokens"] = usage.get("input_tokens", 0) + usage.get(
-                        "output_tokens", 0
-                    )
-            else:
-                if DEBUG_MODE: print("DEBUG: Using fallback token estimation")
-                # Fallback: estimate token usage
-                input_estimate = len(prompt.split()) * 1.3
-                output_estimate = (
-                    len(result.output.split()) * 1.3
-                    if isinstance(result.output, str)
-                    else 0
+                    # Use non-streaming path
+                    result = await self._agent.run(sanitized_prompt)
+
+                # Success - break out of retry loop
+                break
+
+            except Exception as e:
+                # Check if this is a rate limit error (429)
+                error_str = str(e).lower()
+                is_rate_limit = (
+                    "429" in error_str or
+                    "rate limit" in error_str or
+                    "overloaded" in error_str or
+                    "too many requests" in error_str
                 )
-                if DEBUG_MODE: print(f"DEBUG: Input estimate: {input_estimate} (prompt words: {len(prompt.split())})")
-                if DEBUG_MODE: print(f"DEBUG: Output estimate: {output_estimate} (result words: {len(result.output.split()) if isinstance(result.output, str) else 0})")
-                usage = {
-                    "input_tokens": int(input_estimate),
-                    "output_tokens": int(output_estimate),
-                    "total_tokens": int(input_estimate + output_estimate),
-                }
-                if DEBUG_MODE: print(f"DEBUG: Final estimated usage: {usage}")
 
-            return LLMResponse(
-                content=result.output,
-                model=self.model,
-                usage=usage,
-                finish_reason="stop",
-            )
+                last_error = e
 
-        except Exception as e:
-            # Add debug information
-            if DEBUG_MODE: print(f"Debug: Pydantic AI error: {type(e).__name__}: {str(e)}")
-            if hasattr(e, "__dict__"):
-                if DEBUG_MODE: print(f"Debug: Error attributes: {e.__dict__}")
-            raise RuntimeError(
-                f"Pydantic AI completion with usage failed: {str(e)}"
-            ) from e
+                if is_rate_limit and attempt < max_retries:
+                    # Calculate exponential backoff delay
+                    delay = min(base_delay * (2 ** attempt), max_delay)
+
+                    if DEBUG_MODE:
+                        print(f"⚠️  Rate limit hit (attempt {attempt + 1}/{max_retries + 1}). Retrying in {delay:.1f}s...")
+
+                    # Wait before retrying
+                    import asyncio
+                    await asyncio.sleep(delay)
+                    continue
+                else:
+                    # Not a rate limit error, or max retries exceeded - re-raise
+                    raise
+
+        # If we get here without a result, we exhausted retries
+        if last_error:
+            raise last_error
+
+        # Extract usage information from the result
+        usage = {}
+
+        # Debug: Check what attributes the result object has
+        if DEBUG_MODE:
+            print(f"DEBUG result object type: {type(result)}")
+            print(f"DEBUG result attributes: {dir(result)}")
+            if hasattr(result, "_model_name"):
+                print(f"DEBUG result._model_name: {result._model_name}")
+            if hasattr(result, "model"):
+                print(f"DEBUG result.model: {result.model}")
+
+        # Call the usage() method to get actual usage data
+        usage_data = None
+        if hasattr(result, "usage"):
+            try:
+                usage_data = result.usage()  # Call the method!
+            except Exception as e:
+                # Fallback if usage() method fails
+                pass
+
+        if usage_data:
+            # Pydantic AI usage structure may vary
+            # Use new field names first, fall back to deprecated ones
+            import warnings
+            with warnings.catch_warnings():
+                warnings.filterwarnings("ignore", category=DeprecationWarning)
+
+                if hasattr(usage_data, "input_tokens"):
+                    usage["input_tokens"] = usage_data.input_tokens or 0
+                elif hasattr(usage_data, "request_tokens"):
+                    usage["input_tokens"] = usage_data.request_tokens or 0
+
+                if hasattr(usage_data, "output_tokens"):
+                    usage["output_tokens"] = usage_data.output_tokens or 0
+                elif hasattr(usage_data, "response_tokens"):
+                    usage["output_tokens"] = usage_data.response_tokens or 0
+
+            if hasattr(usage_data, "total_tokens"):
+                usage["total_tokens"] = usage_data.total_tokens or 0
+            else:
+                # Calculate total if not available
+                usage["total_tokens"] = usage.get("input_tokens", 0) + usage.get(
+                    "output_tokens", 0
+                )
+        else:
+            if DEBUG_MODE: print("DEBUG: Using fallback token estimation")
+            # Fallback: estimate token usage
+            # Use character-based estimation for better accuracy with CJK languages
+
+            def estimate_tokens(text: str) -> int:
+                """
+                Estimate tokens for text, handling both space-separated and CJK languages.
+
+                Rules:
+                - CJK characters (Chinese, Japanese, Korean): ~1 token per character
+                - Space-separated words (English, etc.): ~1.3 tokens per word
+                - Mixed text: combine both approaches
+                """
+                if not text:
+                    return 0
+
+                # Count CJK characters (Unicode ranges for Chinese, Japanese, Korean)
+                import re
+                cjk_pattern = re.compile(r'[\u4e00-\u9fff\u3040-\u309f\u30a0-\u30ff\uac00-\ud7af]+')
+                cjk_chars = ''.join(cjk_pattern.findall(text))
+                cjk_tokens = len(cjk_chars)  # ~1 token per CJK character
+
+                # Remove CJK characters and count remaining words
+                non_cjk_text = cjk_pattern.sub(' ', text)
+                words = non_cjk_text.split()
+                word_tokens = len(words) * 1.3  # ~1.3 tokens per English word
+
+                return int(cjk_tokens + word_tokens)
+
+            input_estimate = estimate_tokens(prompt)
+            output_estimate = estimate_tokens(result.output) if isinstance(result.output, str) else 0
+
+            if DEBUG_MODE:
+                print(f"DEBUG: Input estimate: {input_estimate} tokens (prompt length: {len(prompt)} chars)")
+                print(f"DEBUG: Output estimate: {output_estimate} tokens (output length: {len(result.output) if isinstance(result.output, str) else 0} chars)")
+
+            usage = {
+                "input_tokens": int(input_estimate),
+                "output_tokens": int(output_estimate),
+                "total_tokens": int(input_estimate + output_estimate),
+            }
+            if DEBUG_MODE: print(f"DEBUG: Final estimated usage: {usage}")
+
+        # Return LLMResponse (for both actual usage and estimated usage paths)
+        if DEBUG_MODE:
+            print(f"DEBUG complete_with_usage: returning model={self._underlying_model_name} (self.model={self.model})")
+
+        return LLMResponse(
+            content=result.output,
+            model=self._underlying_model_name,  # Use clean model name (without provider prefix)
+            usage=usage,
+            finish_reason="stop",
+        )
 
     async def complete_with_tools(
         self,
@@ -345,6 +439,8 @@ def create_pydantic_ai_provider(
             "claude-3-7-sonnet-20250219": "anthropic:claude-3-7-sonnet-20250219",
         },
         "gemini": {
+            # Gemini 3.0 models (newest)
+            "gemini-3-pro-preview": "gemini-3-pro-preview",
             # Gemini 2.5 models (latest)
             "gemini-2.5-flash": "gemini-2.5-flash",
             "gemini-2.5-pro": "gemini-2.5-pro",
@@ -381,6 +477,20 @@ def create_pydantic_ai_provider(
         os.environ["ANTHROPIC_API_KEY"] = api_key
     elif provider_name.lower() == "gemini":
         os.environ["GEMINI_API_KEY"] = api_key
+    elif provider_name.lower() == "moonshot":
+        # Moonshot AI uses OpenAI-compatible API
+        os.environ["OPENAI_API_KEY"] = api_key
+        os.environ["OPENAI_BASE_URL"] = "https://api.moonshot.ai/v1"
+        # Use openai: prefix so Pydantic AI uses OpenAI client
+        # The actual model name will be sent to the custom base URL
+        pydantic_model = f"openai:{model}"
+    elif provider_name.lower() == "deepseek":
+        # DeepSeek AI uses OpenAI-compatible API
+        os.environ["OPENAI_API_KEY"] = api_key
+        os.environ["OPENAI_BASE_URL"] = "https://api.deepseek.com"
+        # Use openai: prefix so Pydantic AI uses OpenAI client
+        # The actual model name will be sent to the custom base URL
+        pydantic_model = f"openai:{model}"
 
     # Pass provider_name explicitly to ensure proper cost tracking
     return PydanticAIProvider(api_key, pydantic_model, provider_name=provider_name.lower())
