@@ -24,6 +24,14 @@ from typing import Any
 import aiosqlite
 
 from ...core.context.models import ChatContext, ChatMessage
+from .migration_manager import MigrationManager
+from .migrations import (
+    migration_001_initial_schema,
+    migration_002_enhance_executions,
+    migration_003_add_client_type,
+    migration_004_backfill_costs,
+    migration_005_normalize_model_names,
+)
 
 
 class ChatStorage:
@@ -38,62 +46,20 @@ class ChatStorage:
         self.db_path = db_path
         self._initialized = False
 
+        # Initialize migration manager
+        self.migration_manager = MigrationManager(db_path)
+        self.migration_manager.register_migration(migration_001_initial_schema)
+        self.migration_manager.register_migration(migration_002_enhance_executions)
+        self.migration_manager.register_migration(migration_003_add_client_type)
+        self.migration_manager.register_migration(migration_004_backfill_costs)
+
     async def initialize(self) -> None:
-        """Initialize database schema"""
+        """Initialize database schema using migrations"""
         if self._initialized:
             return
 
-        async with aiosqlite.connect(str(self.db_path)) as db:
-            await db.executescript(
-                """
-                CREATE TABLE IF NOT EXISTS chats (
-                    id TEXT PRIMARY KEY,
-                    title TEXT NOT NULL,
-                    created_at TIMESTAMP NOT NULL,
-                    updated_at TIMESTAMP NOT NULL,
-                    metadata TEXT DEFAULT '{}',
-                    archived BOOLEAN DEFAULT FALSE
-                );
-
-                CREATE TABLE IF NOT EXISTS messages (
-                    id INTEGER PRIMARY KEY AUTOINCREMENT,
-                    chat_id TEXT NOT NULL,
-                    message_id TEXT NOT NULL,
-                    role TEXT NOT NULL,
-                    content TEXT NOT NULL,
-                    timestamp TIMESTAMP NOT NULL,
-                    metadata TEXT DEFAULT '{}',
-                    FOREIGN KEY (chat_id) REFERENCES chats (id) ON DELETE CASCADE
-                );
-
-                CREATE TABLE IF NOT EXISTS chat_tags (
-                    chat_id TEXT NOT NULL,
-                    tag TEXT NOT NULL,
-                    PRIMARY KEY (chat_id, tag),
-                    FOREIGN KEY (chat_id) REFERENCES chats (id) ON DELETE CASCADE
-                );
-
-                CREATE TABLE IF NOT EXISTS executions (
-                    id INTEGER PRIMARY KEY AUTOINCREMENT,
-                    chat_id TEXT NOT NULL,
-                    function_name TEXT NOT NULL,
-                    parameters TEXT DEFAULT '{}',
-                    result TEXT DEFAULT '{}',
-                    timestamp TIMESTAMP NOT NULL,
-                    success BOOLEAN DEFAULT FALSE,
-                    FOREIGN KEY (chat_id) REFERENCES chats (id) ON DELETE CASCADE
-                );
-
-                -- Indexes for performance
-                CREATE INDEX IF NOT EXISTS idx_chats_updated_at ON chats (updated_at DESC);
-                CREATE INDEX IF NOT EXISTS idx_chats_archived ON chats (archived);
-                CREATE INDEX IF NOT EXISTS idx_messages_chat_id ON messages (chat_id);
-                CREATE INDEX IF NOT EXISTS idx_messages_timestamp ON messages (timestamp);
-                CREATE INDEX IF NOT EXISTS idx_chat_tags_tag ON chat_tags (tag);
-                CREATE INDEX IF NOT EXISTS idx_executions_chat_id ON executions (chat_id);
-            """
-            )
-            await db.commit()
+        # Run all pending migrations
+        await self.migration_manager.migrate()
 
         self._initialized = True
 
@@ -576,3 +542,160 @@ class ChatStorage:
         except Exception as e:
             print(f"Error cleaning up old data: {e}")
             return {"deleted_chats": 0}
+
+    async def log_execution(
+        self,
+        execution_id: str,
+        function_name: str,
+        function_category: str | None = None,
+        model: str | None = None,
+        provider: str | None = None,
+        success: bool = False,
+        error_code: str | None = None,
+        error_message: str | None = None,
+        time_to_first_token_ms: int | None = None,
+        total_execution_time_ms: int | None = None,
+        input_tokens: int = 0,
+        output_tokens: int = 0,
+        cost_usd: float = 0.0,
+        chat_id: str | None = None,
+        session_id: str | None = None,
+        user_id: str | None = None,
+        parameters: dict[str, Any] | None = None,
+        result: dict[str, Any] | None = None,
+    ) -> bool:
+        """
+        Log function execution to database.
+
+        Args:
+            execution_id: Unique execution identifier
+            function_name: Name of function executed
+            function_category: Category (content, code, analysis, etc.)
+            model: LLM model used
+            provider: LLM provider
+            success: Whether execution succeeded
+            error_code: Error code if failed
+            error_message: Error message if failed
+            time_to_first_token_ms: Latency to first token
+            total_execution_time_ms: Total execution time
+            input_tokens: Input token count
+            output_tokens: Output token count
+            cost_usd: Estimated cost in USD
+            chat_id: Associated chat ID
+            session_id: Session identifier
+            user_id: User identifier
+            parameters: Function parameters (legacy)
+            result: Function result (legacy)
+
+        Returns:
+            True if logged successfully
+        """
+        await self.initialize()
+
+        try:
+            async with aiosqlite.connect(str(self.db_path)) as db:
+                await db.execute(
+                    """
+                    INSERT INTO executions (
+                        execution_id, timestamp, function_name, function_category,
+                        model, provider, success, error_code, error_message,
+                        time_to_first_token_ms, total_execution_time_ms,
+                        input_tokens, output_tokens, cost_usd,
+                        chat_id, session_id, user_id, parameters, result
+                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
+                    """,
+                    (
+                        execution_id,
+                        datetime.now().isoformat(),
+                        function_name,
+                        function_category,
+                        model,
+                        provider,
+                        success,
+                        error_code,
+                        error_message,
+                        time_to_first_token_ms,
+                        total_execution_time_ms,
+                        input_tokens,
+                        output_tokens,
+                        cost_usd,
+                        chat_id,
+                        session_id,
+                        user_id,
+                        json.dumps(parameters or {}),
+                        json.dumps(result or {}),
+                    ),
+                )
+                await db.commit()
+                return True
+
+        except Exception as e:
+            print(f"Error logging execution {execution_id}: {e}")
+            return False
+
+    async def log_executions_batch(
+        self, executions: list[dict[str, Any]]
+    ) -> dict[str, int]:
+        """
+        Log multiple executions in a single transaction (batch insert).
+
+        Args:
+            executions: List of execution dicts with fields matching log_execution()
+
+        Returns:
+            Dict with success/failed counts
+        """
+        await self.initialize()
+
+        success_count = 0
+        failed_count = 0
+
+        try:
+            async with aiosqlite.connect(str(self.db_path)) as db:
+                for execution in executions:
+                    try:
+                        await db.execute(
+                            """
+                            INSERT INTO executions (
+                                execution_id, timestamp, function_name, function_category,
+                                model, provider, success, error_code, error_message,
+                                time_to_first_token_ms, total_execution_time_ms,
+                                input_tokens, output_tokens, cost_usd,
+                                chat_id, session_id, user_id, client_type, parameters, result
+                            ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
+                            """,
+                            (
+                                execution.get("execution_id"),
+                                execution.get("timestamp", datetime.now().isoformat()),
+                                execution.get("function_name"),
+                                execution.get("function_category"),
+                                execution.get("model"),
+                                execution.get("provider"),
+                                execution.get("success", False),
+                                execution.get("error_code"),
+                                execution.get("error_message"),
+                                execution.get("time_to_first_token_ms"),
+                                execution.get("total_execution_time_ms"),
+                                execution.get("input_tokens", 0),
+                                execution.get("output_tokens", 0),
+                                execution.get("cost_usd", 0.0),
+                                execution.get("chat_id"),
+                                execution.get("session_id"),
+                                execution.get("user_id"),
+                                execution.get("client_type", "cli"),
+                                json.dumps(execution.get("parameters", {})),
+                                json.dumps(execution.get("result", {})),
+                            ),
+                        )
+                        success_count += 1
+                    except Exception as e:
+                        print(f"Error in batch logging execution: {e}")
+                        failed_count += 1
+
+                await db.commit()
+
+        except Exception as e:
+            print(f"Error in batch execution logging: {e}")
+            failed_count += len(executions) - success_count
+
+        return {"success": success_count, "failed": failed_count}
