@@ -99,10 +99,12 @@ def print_session_summary(metadata: dict[str, Any], output_mode: str = "STANDARD
             cost_str = f"${cost:.2f}"
         summary_parts.append(f"💰 {cost_str}")
 
-    # Model
+    # Model (strip openai: prefix for OpenAI-compatible providers like Moonshot/DeepSeek)
     model = metadata.get("model")
     if model:
-        summary_parts.append(f"🤖 {model}")
+        # Strip "openai:" prefix if present (used for OpenAI-compatible providers)
+        display_model = model.replace("openai:", "") if model.startswith("openai:") else model
+        summary_parts.append(f"🤖 {display_model}")
 
     # Print compact summary on single line (with blank line above for readability)
     print()  # Single blank line for readability
@@ -370,6 +372,9 @@ async def handle_ai_command(route: Any, config_manager: Any, output_config: Any,
 
     offline = args.get("offline", False)
 
+    # v0.8.0: Extract model override if provided
+    model = args.get("model")
+
     # Create WebSocket client (already configured with --host override above)
     client = AiiCLIClient(config_manager)
 
@@ -396,6 +401,7 @@ async def handle_ai_command(route: Any, config_manager: Any, output_config: Any,
             user_input=user_input,
             output_mode=output_mode,
             offline=offline,
+            model=model,  # v0.8.0: Pass model override
             spinner=processing_spinner  # Pass spinner so it can be stopped on first token
         )
 
